@@ -31,7 +31,7 @@ $language = array(
 'oslist'                  => 'Rendszerek listája',
 'resolutionlist'          => 'Megoldások listája',
 'versionlist'             => 'Változatok listája',
-'severitylist'            => 'Előfordulások listája',
+'severitylist'            => 'Súlyosságok listája',
 'listnote'                => 'Megjegyzés: A "megjelenít" kijelölőnégyzet törlése megszünteti az adott elem használatát, így ez a módosítás megváltoztathat pár hibajegyet, ahol ez használatban van. A "név" mező megváltozatása az összes olyan hibajegyben megváltozik, ahol ez használatban van. A nem törölhető bejegyzések vagy törlésre védettek, vagy pedig szükségesek a helyes működéshez, illetve már felhasználásra kerültek.',
 'name'                    => 'Név',
 'order'                   => 'Sorrend',
@@ -187,7 +187,7 @@ $language = array(
 'status'                  => 'Státusz',
 'assignedto'              => 'Felhasználó hozzárendelése',
 'operatingsystem'         => 'Rendszer',
-'severity'                => 'Gyakoriság',
+'severity'                => 'Súlyosság',
 'reportedversion'         => 'Jelentett változat',
 'dueinversion'            => 'Esedékesség',
 'undecided'               => 'határozatlan',
@@ -429,7 +429,7 @@ Tisztelettel,',
 'categoryowner'           => 'Ön azért kapta ezt azt, mert a hibajegy kategóriájának tulajdonosa.',
 'tasksummary'             => 'Hibajegy összefoglalása:',
 'newtaskadded'            => 'Az új hibajegy hozzáadva.',
-'summaryanddetails'       => 'Ki kell töltenie az összegzést és a részletes leírást is.',
+'summaryanddetails'       => 'Ki kell töltenie az összegzést és a részletes leírást is. Továbbá anonym felhasználó esetén ellenőrizze hogy megadott-e e-mail címet!',
 'goback'                  => 'Vissza.',
 'messagefrom'             => 'Ez egy üzenet a hibajegy rendszertől a ',
 'hasjustmodified'         => 'módosította a következő hibajegyet.',
@@ -623,7 +623,7 @@ Tisztelettel,',
 'to'                      => '-',
 'oldestfirst'             => 'Régebiek előre',
 'recentfirst'             => 'Legfrissebbek előre',
-'severityrep'             => 'Gyakoriság riport',
+'severityrep'             => 'Súlyossági riport',
 'totalopen'               => 'Összes nyitott hibajegy',
 'age'                     => 'Kor',
 'agerep'                  => 'Kor riport',
@@ -842,7 +842,9 @@ Tisztelettel,',
 'assign_to_self'	=> 'Önmagamhoz rendelés',
 'assign_others_to_self'	=> 'Mások hozzárendelése',
 'view_reports'		=> 'Riportok megtekintése',
-'add_votes'		=> 'Szavazat leadása'
+'add_votes'		=> 'Szavazat leadása',
+'showasassignees'         => 'Hozzárendelhető személy',
+'find'		=> 'Keresés'
 );
 
-?>
+?>
\ No newline at end of file
